@@ -7,10 +7,10 @@ use warnings;
 
 package POSIX::1003;
 use vars '$VERSION';
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 use Carp 'croak';
 
 { use XSLoader;
@@ -19,18 +19,23 @@ use Carp 'croak';
 }
 
 my $in_constant_table;
-BEGIN { $in_constant_table = qr/ ^ (?:
-   _SC_      # sysconf
- | _CS_      # confstr
- | _PC_      # pathconf
- | _POSIX    # property
- | UL_       # ulimit
- | RLIM      # rlimit
- | GET_|SET_ # rlimit aix
- | POLL      # poll
- | SIG[^_]   # signals
- ) /x;
- }
+BEGIN { $in_constant_table = qr/
+   ^_CS_    # confstr
+ | ^GET_    # rlimit
+ | ^O_      # fdio
+ | ^_PC_    # pathconf
+ | ^POLL    # poll
+ | ^_POSIX  # property
+ | ^RLIM    # rlimit
+ | ^_SC_    # sysconf
+ | ^S_      # stat
+ | ^SEEK_   # fdio
+ | ^SET_    # rlimit aix
+ | ^SIG[^_] # signals
+ | ^UL_     # ulimit
+ | _OK$     # access
+ /x
+};
 
 sub import(@)
 {   my $class = shift;
@@ -131,7 +136,7 @@ sub exampleValue($)
 
 package POSIX::1003::ReadOnlyTable;
 use vars '$VERSION';
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 sub TIEHASH($) { bless $_[1], $_[0] }
 sub FETCH($)   { $_[0]->{$_[1]} }
