@@ -7,7 +7,7 @@ use strict;
 
 package POSIX::1003::Signals;
 use vars '$VERSION';
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 use base 'POSIX::1003';
 
@@ -35,7 +35,7 @@ our %EXPORT_TAGS =
   , status    => \@states
   , constants => \@constants
   , functions => \@functions
-  , table     => [ '%signals' ]
+  , tables    => [ '%signals' ]
   );
 
 our @IN_CORE = qw/kill/;
